summaryrefslogtreecommitdiffstats
path: root/karm/plannerparser.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'karm/plannerparser.cpp')
-rw-r--r--karm/plannerparser.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/karm/plannerparser.cpp b/karm/plannerparser.cpp
index 7ac13a5e..a1f83eb2 100644
--- a/karm/plannerparser.cpp
+++ b/karm/plannerparser.cpp
@@ -35,9 +35,9 @@ test cases:
kdDebug() << "entering constructor to import planner tasks" << endl;
_taskView=tv;
level=0;
- if (_taskView->current_item()) if (_taskView->current_item()->parent())
+ if (_taskView->current_item()) if (_taskView->current_item()->tqparent())
{
- task = _taskView->current_item()->parent();
+ task = _taskView->current_item()->tqparent();
level=1;
}
}
@@ -67,13 +67,13 @@ test cases:
}
// at the moment, task is still the old task or the old father task (if an endElement occurred) or not existing (if the
// new task is a top-level-task). Make task the parenttask, if existing.
DesktopList dl;
if (level++>0)
{
- parentTask=task;
- task = new Task(taskName, 0, 0, dl, parentTask);
- task->setUid(_taskView->storage()->addTask(task, parentTask));
+ tqparentTask=task;
+ task = new Task(taskName, 0, 0, dl, tqparentTask);
+ task->setUid(_taskView->storage()->addTask(task, tqparentTask));
}
else
{
@@ -92,7 +92,7 @@ test cases:
// only <task>s within <tasks> increased level, so only decrease for <task>s within <tasks>
if (withInTasks)
{
- if (qName=="task") if (level-->=0) task=task->parent();
+ if (qName=="task") if (level-->=0) task=task->tqparent();
if (qName=="tasks") withInTasks=false;
}
return true;
@@ -67,13 +67,13 @@ test cases:
}
// at the moment, task is still the old task or the old father task (if an endElement occurred) or not existing (if the
- // new task is a top-level-task). Make task the parenttask, if existing.
+ // new task is a top-level-task). Make task the tqparenttask, if existing.
DesktopList dl;
if (level++>0)